#! /bin/bash

set -x

exec 2>&1 > update.log

run() {
    pkgs=$1
    outf=$2
    if [[ -z "$pkgs" ]]; then
	args=--upgradable
    fi
    apt list $args $pkgs 2> /dev/null  | tee $outf.txt | ./bin/parseapt.py | tee $outf.csv
}

sudo apt-get update

run "xc-usense xc gpioserver ragmon cnfmon python3-ilff icm20649-spi" apt-usense-list
run "" apt-list

exit 0
